@@ -39,17 +39,20 @@ class CustomFormMixin:
         )
 
     def get_layout(self):
-        formfields = filter_fieldlist(
-            self.model,
-            [f for f in self.fields if isinstance(f, str)] if self.fields else None,
-            for_form=True,
-        )
-        ret = hg.BaseElement()
-        for field in self.fields or formfields:
-            if field in formfields:
-                ret.append(breadlayout.forms.FormField(field))
-            else:
-                ret.append(field)
+        if hasattr(self, "layout") and self.layout is not None:
+            ret = self.layout
+        else:
+            formfields = filter_fieldlist(
+                self.model,
+                [f for f in self.fields if isinstance(f, str)] if self.fields else None,
+                for_form=True,
+            )
+            ret = hg.BaseElement()
+            for field in self.fields or formfields:
+                if field in formfields:
+                    ret.append(breadlayout.forms.FormField(field))
+                else:
+                    ret.append(field)
 
         if self.ajax_urlparameter in self.request.GET:
             return breadlayout.forms.Form(hg.C("form"), ret)
@@ -126,7 +129,7 @@ class BreadView:
 
     layout: typing.Optional[hg.BaseElement] = None
     _layout_cached: typing.Optional[hg.BaseElement] = None
-    ajax_urlparameter = "asajax"
+    ajax_urlparameter = settings.AJAX_URLPARAMETER
     page_layout: typing.Optional[
         typing.Callable[[menu.Menu, hg.BaseElement], hg.BaseElement]
     ] = None
@@ -153,9 +156,6 @@ class BreadView:
         if isinstance(self.page_layout, str):
             self.page_layout = import_string(self.page_layout)
 
-    def get_page_layout(self, menu, content_layout):
-        return self.page_layout(menu, content_layout)
-
     def get_layout(self):
         """Returns the layout for this view, returns the ``layout`` attribute by default.
         Either set the ``layout`` attribute or override this method."""
@@ -167,7 +167,7 @@ class BreadView:
         response_kwargs.setdefault("content_type", self.content_type)
         ret = self._get_layout_cached()
         if self.ajax_urlparameter not in self.request.GET:
-            ret = self.get_page_layout(menu.main, ret)
+            ret = self.page_layout(menu.main, ret)
 
         return breadlayout.render(self.request, ret, context, **response_kwargs)
 
